@@ -6,10 +6,12 @@ from django.db import models
 from django.utils.text import capfirst
 from upy import forms
 
+
 class NullTrueFieldBase(models.SubfieldBase):
     def to_python(self, value):
         return value == True
 
+
 class NullTrueField(models.NullBooleanField):   
     __metaclass__ = NullTrueFieldBase 
     def to_python(self, value):
@@ -31,15 +33,18 @@ class NullTrueField(models.NullBooleanField):
         defaults.update(kwargs)
         return super(NullTrueField, self).formfield(**defaults)
     
+
 # ISO 3166-1 country names and codes adapted from http://opencountrycodes.appspot.com/python/
-CONTINENTS = [(u'africa',_(u'Africa')),
-            (u'antarctica',_(u'Antarctica')),
-            (u'asia',_(u'Asia')),
-            (u'europe',_(u'Europe')),
-            (u'north-america',_(u'North America')),
-            (u'oceania',_(u'Oceania')),
-            (u'south-america',_(u'South America')),
-            ]
+CONTINENTS = [
+    (u'africa', _(u'Africa')),
+    (u'antarctica', _(u'Antarctica')),
+    (u'asia', _(u'Asia')),
+    (u'europe', _(u'Europe')),
+    (u'north-america', _(u'North America')),
+    (u'oceania', _(u'Oceania')),
+    (u'south-america', _(u'South America')),
+]
+
 
 COUNTRIES = (
     ('GB', _('United Kingdom')), 
@@ -291,268 +296,270 @@ COUNTRIES = (
 )
 
 CONTINENT_COUNTRIES = (
-       (_(u'Africa'),(
-            ('DZ',_(u'Algeria')),
-            ('AO',_(u'Angola')),
-            ('BJ',_(u'Benin')),
-            ('BW',_(u'Botswana')),
-            ('BF',_(u'Burkina Faso')),
-            ('BI',_(u'Burundi')),
-            ('CM',_(u'Cameroon')),
-            ('CV',_(u'Cape Verde')),
-            ('CF',_(u'Central African Republic')),
-            ('TD',_(u'Chad')),
-            ('KM',_(u'Comoros')),
-            ('CG',_(u'Congo')),
-            ('CD',_(u'Congo, The Democratic Republic of the')),
-            ('CI',_(u'Cote d\'Ivoire')),
-            ('DJ',_(u'Djibouti')),
-            ('EG',_(u'Egypt')),
-            ('GQ',_(u'Equatorial Guinea')),
-            ('ER',_(u'Eritrea')),
-            ('ET',_(u'Ethiopia')),
-            ('GA',_(u'Gabon')),
-            ('GM',_(u'Gambia')),
-            ('GH',_(u'Ghana')),
-            ('GN',_(u'Guinea')),
-            ('GW',_(u'Guinea-Bissau')),
-            ('KE',_(u'Kenya')),
-            ('LS',_(u'Lesotho')),
-            ('LR',_(u'Liberia')),
-            ('LY',_(u'Libyan Arab Jamahiriya')),
-            ('MG',_(u'Madagascar')),
-            ('YT',_(u'Mayotte')),
-            ('MW',_(u'Malawi')),
-            ('ML',_(u'Mali')),
-            ('MR',_(u'Mauritania')),
-            ('MU',_(u'Mauritius')),
-            ('MA',_(u'Morocco')),
-            ('MZ',_(u'Mozambique')),
-            ('NA',_(u'Namibia')),
-            ('NE',_(u'Niger')),
-            ('NG',_(u'Nigeria')),
-            ('RE',_(u'Reunion')),
-            ('RW',_(u'Rwanda')),
-            ('SH',_(u'Saint Helena')),
-            ('ST',_(u'Sao Tome and Principe')),
-            ('SN',_(u'Senegal')),
-            ('SC',_(u'Seychelles')),
-            ('SL',_(u'Sierra Leone')),
-            ('SO',_(u'Somalia')),
-            ('ZA',_(u'South Africa')),
-            ('SD',_(u'Sudan')),
-            ('SZ',_(u'Swaziland')),
-            ('TZ',_(u'Tanzania, United Republic of')),
-            ('TG',_(u'Togo')),
-            ('TN',_(u'Tunisia')),
-            ('UG',_(u'Uganda')),
-            ('EH',_(u'Western Sahara')),
-            ('ZM',_(u'Zambia')),
-            ('ZW',_(u'Zimbabwe')),
-            )),
-        (_(u'Antarctica'),(
-            ('AQ',_(u'Antarctica')),
-            ('BV',_(u'Bouvet Island')),
-            ('TF',_(u'French Southern Territories')),
-            ('HM',_(u'Heard Island and McDonald Islands')),
-            )),
-        (_(u'Asia'),(
-            ('AF',_(u'Afghanistan')),
-            ('BH',_(u'Bahrain')),
-            ('BD',_(u'Bangladesh')),
-            ('BT',_(u'Bhutan')),
-            ('IO',_(u'British Indian Ocean Territory')),
-            ('BN',_(u'Brunei Darussalam')),
-            ('KH',_(u'Cambodia')),
-            ('CN',_(u'China')),
-            ('HK',_(u'Hong Kong')),
-            ('IR',_(u'Iran, Islamic Republic of')),
-            ('IN',_(u'India')),
-            ('ID',_(u'Indonesia')),
-            ('IQ',_(u'Iraq')),
-            ('IL',_(u'Israel')),
-            ('JP',_(u'Japan')),
-            ('JO',_(u'Jordan')),
-            ('KZ',_(u'Kazakhstan')),
-            ('KW',_(u'Kuwait')),
-            ('KP',_(u'Korea, Democratic People\'s Republic of')),
-            ('KR',_(u'Korea, Republic of')),
-            ('LA',_(u'Lao People\'s Democratic Republic')),
-            ('KG',_(u'Kyrgyzstan')),
-            ('LB',_(u'Lebanon')),
-            ('MO',_(u'Macao')),
-            ('MY',_(u'Malaysia')),
-            ('MV',_(u'Maldives')),
-            ('MM',_(u'Myanmar')),
-            ('MN',_(u'Mongolia')),
-            ('NP',_(u'Nepal')),
-            ('OM',_(u'Oman')),
-            ('PK',_(u'Pakistan')),
-            ('PS',_(u'Palestinian Territory, Occupied')),
-            ('PH',_(u'Philippines')),
-            ('QA',_(u'Qatar')),
-            ('RU',_(u'Russian Federation')),
-            ('SA',_(u'Saudi Arabia')),
-            ('SG',_(u'Singapore')),
-            ('SY',_(u'Syrian Arab Republic')),
-            ('LK',_(u'Sri Lanka')),
-            ('TJ',_(u'Tajikistan')),
-            ('TW',_(u'Taiwan, Province of China')),
-            ('TH',_(u'Thailand')),
-            ('TL',_(u'Timor-Leste')),
-            ('TR',_(u'Turkey')),
-            ('TM',_(u'Turkmenistan')),
-            ('AE',_(u'United Arab Emirates')),
-            ('UZ',_(u'Uzbekistan')),
-            ('VN',_(u'Vietnam')),
-            ('YE',_(u'Yemen')),
-            )),
-        (_(u'Europe'),(
-            ('AX',_(u'Aland Islands')),
-            ('AL',_(u'Albania')),
-            ('AD',_(u'Andorra')),
-            ('AM',_(u'Armenia')),
-            ('AT',_(u'Austria')),
-            ('AZ',_(u'Azerbaijan')),
-            ('BY',_(u'Belarus')),
-            ('BE',_(u'Belgium')),
-            ('BA',_(u'Bosnia and Herzegovina')),
-            ('BG',_(u'Bulgaria')),
-            ('HR',_(u'Croatia')),
-            ('CY',_(u'Cyprus')),
-            ('CZ',_(u'Czech Republic')),
-            ('DK',_(u'Denmark')),
-            ('EE',_(u'Estonia')),
-            ('FO',_(u'Faroe Islands')),
-            ('FI',_(u'Finland')),
-            ('FR',_(u'France')),
-            ('GE',_(u'Georgia')),
-            ('DE',_(u'Germany')),
-            ('GI',_(u'Gibraltar')),
-            ('GR',_(u'Greece')),
-            ('GL',_(u'Greenland')),
-            ('GG',_(u'Guernsey')),
-            ('HU',_(u'Hungary')),
-            ('IS',_(u'Iceland')),
-            ('IE',_(u'Ireland')),
-            ('IM',_(u'Isle of Man')),
-            ('IT',_(u'Italy')),
-            ('JE',_(u'Jersey')),
-            ('LV',_(u'Latvia')),
-            ('LI',_(u'Liechtenstein')),
-            ('LT',_(u'Lithuania')),
-            ('LU',_(u'Luxembourg')),
-            ('MK',_(u'Macedonia, The Former Yugoslav Republic of')),
-            ('MT',_(u'Malta')),
-            ('MD',_(u'Moldova')),
-            ('MC',_(u'Monaco')),
-            ('ME',_(u'Montenegro')),
-            ('NL',_(u'Netherlands')),
-            ('NO',_(u'Norway')),
-            ('PL',_(u'Poland')),
-            ('PT',_(u'Portugal')),
-            ('RO',_(u'Romania')),
-            ('SM',_(u'San Marino')),
-            ('RS',_(u'Serbia')),
-            ('SK',_(u'Slovakia')),
-            ('SI',_(u'Slovenia')),
-            ('ES',_(u'Spain')),
-            ('SJ',_(u'Svalbard and Jan Mayen')),
-            ('SE',_(u'Sweden')),
-            ('CH',_(u'Switzerland')),
-            ('UA',_(u'Ukraine')),
-            ('GB',_(u'United Kingdom')),
-            ('VA',_(u'Holy See (Vatican City State)')),
-            )),
-        (_(u'North America'),(
-            ('AS',_(u'American Samoa')),
-            ('AI',_(u'Anguilla')),
-            ('AG',_(u'Antigua and Barbuda')),
-            ('AW',_(u'Aruba')),
-            ('BS',_(u'Bahamas')),
-            ('BB',_(u'Barbados')),
-            ('BZ',_(u'Belize')),
-            ('BM',_(u'Bermuda')),
-            ('CA',_(u'Canada')),
-            ('KY',_(u'Cayman Islands')),
-            ('CR',_(u'Costa Rica')),
-            ('CU',_(u'Cuba')),
-            ('DM',_(u'Dominica')),
-            ('DO',_(u'Dominican Republic')),
-            ('SV',_(u'El Salvador')),
-            ('GD',_(u'Grenada')),
-            ('GP',_(u'Guadeloupe')),
-            ('GT',_(u'Guatemala')),
-            ('HT',_(u'Haiti')),
-            ('HN',_(u'Honduras')),
-            ('JM',_(u'Jamaica')),
-            ('MX',_(u'Mexico')),
-            ('MS',_(u'Montserrat')),
-            ('AN',_(u'Netherlands Antilles')),
-            ('NI',_(u'Nicaragua')),
-            ('PA',_(u'Panama')),
-            ('PR',_(u'Puerto Rico')),
-            ('BL',_(u'Saint Barthelemy')),
-            ('KN',_(u'Saint Kitts and Nevis')),
-            ('LC',_(u'Saint Lucia')),
-            ('MF',_(u'Saint Martin')),
-            ('PM',_(u'Saint Pierre and Miquelon')),
-            ('VC',_(u'Saint Vincent and the Grenadines')),
-            ('TT',_(u'Trinidad and Tobago')),
-            ('TC',_(u'Turks and Caicos Islands')),
-            ('US',_(u'United States')),
-            ('UM',_(u'United States Minor Outlying Islands')),
-            ('VG',_(u'Virgin Islands, British')),
-            ('VI',_(u'Virgin Islands, U.S.')),
-            )),
-        (_(u'Oceania'),(
-            ('AU',_(u'Australia')),
-            ('CX',_(u'Christmas Island')),
-            ('CC',_(u'Cocos (Keeling) Islands')),
-            ('CK',_(u'Cook Islands')),
-            ('FJ',_(u'Fiji')),
-            ('PF',_(u'French Polynesia')),
-            ('GU',_(u'Guam')),
-            ('KI',_(u'Kiribati')),
-            ('MH',_(u'Marshall Islands')),
-            ('FM',_(u'Micronesia, Federated States of')),
-            ('NR',_(u'Nauru')),
-            ('NC',_(u'New Caledonia')),
-            ('NZ',_(u'New Zealand')),
-            ('NU',_(u'Niue')),
-            ('NF',_(u'Norfolk Island')),
-            ('MP',_(u'Northern Mariana Islands')),
-            ('PW',_(u'Palau')),
-            ('PG',_(u'Papua New Guinea')),
-            ('PN',_(u'Pitcairn')),
-            ('WS',_(u'Samoa')),
-            ('SB',_(u'Solomon Islands')),
-            ('TK',_(u'Tokelau')),
-            ('TO',_(u'Tonga')),
-            ('TV',_(u'Tuvalu')),
-            ('VU',_(u'Vanuatu')),
-            ('WF',_(u'Wallis and Futuna')),
-            )),
-        (_(u'South America'),(
-            ('AR',_(u'Argentina')),
-            ('BO',_(u'Bolivia')),
-            ('BR',_(u'Brazil')),
-            ('CL',_(u'Chile')),
-            ('CO',_(u'Colombia')),
-            ('EC',_(u'Ecuador')),
-            ('FK',_(u'Falkland Islands (Malvinas)')),
-            ('GF',_(u'French Guiana')),
-            ('GY',_(u'Guyana')),
-            ('MQ',_(u'Martinique')),
-            ('PY',_(u'Paraguay')),
-            ('PE',_(u'Peru')),
-            ('GS',_(u'South Georgia and the South Sandwich Islands')),
-            ('SR',_(u'Suriname')),
-            ('UY',_(u'Uruguay')),
-            ('VE',_(u'Venezuela')),
-            )),
-       )
-             
+    (_(u'Africa'),(
+        ('DZ', _(u'Algeria')),
+        ('AO', _(u'Angola')),
+        ('BJ', _(u'Benin')),
+        ('BW', _(u'Botswana')),
+        ('BF', _(u'Burkina Faso')),
+        ('BI', _(u'Burundi')),
+        ('CM', _(u'Cameroon')),
+        ('CV', _(u'Cape Verde')),
+        ('CF', _(u'Central African Republic')),
+        ('TD', _(u'Chad')),
+        ('KM', _(u'Comoros')),
+        ('CG', _(u'Congo')),
+        ('CD', _(u'Congo, The Democratic Republic of the')),
+        ('CI', _(u'Cote d\'Ivoire')),
+        ('DJ', _(u'Djibouti')),
+        ('EG', _(u'Egypt')),
+        ('GQ', _(u'Equatorial Guinea')),
+        ('ER', _(u'Eritrea')),
+        ('ET', _(u'Ethiopia')),
+        ('GA', _(u'Gabon')),
+        ('GM', _(u'Gambia')),
+        ('GH', _(u'Ghana')),
+        ('GN', _(u'Guinea')),
+        ('GW', _(u'Guinea-Bissau')),
+        ('KE', _(u'Kenya')),
+        ('LS', _(u'Lesotho')),
+        ('LR', _(u'Liberia')),
+        ('LY', _(u'Libyan Arab Jamahiriya')),
+        ('MG', _(u'Madagascar')),
+        ('YT', _(u'Mayotte')),
+        ('MW', _(u'Malawi')),
+        ('ML', _(u'Mali')),
+        ('MR', _(u'Mauritania')),
+        ('MU', _(u'Mauritius')),
+        ('MA', _(u'Morocco')),
+        ('MZ', _(u'Mozambique')),
+        ('NA', _(u'Namibia')),
+        ('NE', _(u'Niger')),
+        ('NG', _(u'Nigeria')),
+        ('RE', _(u'Reunion')),
+        ('RW', _(u'Rwanda')),
+        ('SH', _(u'Saint Helena')),
+        ('ST', _(u'Sao Tome and Principe')),
+        ('SN', _(u'Senegal')),
+        ('SC', _(u'Seychelles')),
+        ('SL', _(u'Sierra Leone')),
+        ('SO', _(u'Somalia')),
+        ('ZA', _(u'South Africa')),
+        ('SD', _(u'Sudan')),
+        ('SZ', _(u'Swaziland')),
+        ('TZ', _(u'Tanzania, United Republic of')),
+        ('TG', _(u'Togo')),
+        ('TN', _(u'Tunisia')),
+        ('UG', _(u'Uganda')),
+        ('EH', _(u'Western Sahara')),
+        ('ZM', _(u'Zambia')),
+        ('ZW', _(u'Zimbabwe')),
+        )),
+    (_(u'Antarctica'),(
+        ('AQ', _(u'Antarctica')),
+        ('BV', _(u'Bouvet Island')),
+        ('TF', _(u'French Southern Territories')),
+        ('HM', _(u'Heard Island and McDonald Islands')),
+        )),
+    (_(u'Asia'),(
+        ('AF', _(u'Afghanistan')),
+        ('BH', _(u'Bahrain')),
+        ('BD', _(u'Bangladesh')),
+        ('BT', _(u'Bhutan')),
+        ('IO', _(u'British Indian Ocean Territory')),
+        ('BN', _(u'Brunei Darussalam')),
+        ('KH', _(u'Cambodia')),
+        ('CN', _(u'China')),
+        ('HK', _(u'Hong Kong')),
+        ('IR', _(u'Iran, Islamic Republic of')),
+        ('IN', _(u'India')),
+        ('ID', _(u'Indonesia')),
+        ('IQ', _(u'Iraq')),
+        ('IL', _(u'Israel')),
+        ('JP', _(u'Japan')),
+        ('JO', _(u'Jordan')),
+        ('KZ', _(u'Kazakhstan')),
+        ('KW', _(u'Kuwait')),
+        ('KP', _(u'Korea, Democratic People\'s Republic of')),
+        ('KR', _(u'Korea, Republic of')),
+        ('LA', _(u'Lao People\'s Democratic Republic')),
+        ('KG', _(u'Kyrgyzstan')),
+        ('LB', _(u'Lebanon')),
+        ('MO', _(u'Macao')),
+        ('MY', _(u'Malaysia')),
+        ('MV', _(u'Maldives')),
+        ('MM', _(u'Myanmar')),
+        ('MN', _(u'Mongolia')),
+        ('NP', _(u'Nepal')),
+        ('OM', _(u'Oman')),
+        ('PK', _(u'Pakistan')),
+        ('PS', _(u'Palestinian Territory, Occupied')),
+        ('PH', _(u'Philippines')),
+        ('QA', _(u'Qatar')),
+        ('RU', _(u'Russian Federation')),
+        ('SA', _(u'Saudi Arabia')),
+        ('SG', _(u'Singapore')),
+        ('SY', _(u'Syrian Arab Republic')),
+        ('LK', _(u'Sri Lanka')),
+        ('TJ', _(u'Tajikistan')),
+        ('TW', _(u'Taiwan, Province of China')),
+        ('TH', _(u'Thailand')),
+        ('TL', _(u'Timor-Leste')),
+        ('TR', _(u'Turkey')),
+        ('TM', _(u'Turkmenistan')),
+        ('AE', _(u'United Arab Emirates')),
+        ('UZ', _(u'Uzbekistan')),
+        ('VN', _(u'Vietnam')),
+        ('YE', _(u'Yemen')),
+        )),
+    (_(u'Europe'),(
+        ('AX', _(u'Aland Islands')),
+        ('AL', _(u'Albania')),
+        ('AD', _(u'Andorra')),
+        ('AM', _(u'Armenia')),
+        ('AT', _(u'Austria')),
+        ('AZ', _(u'Azerbaijan')),
+        ('BY', _(u'Belarus')),
+        ('BE', _(u'Belgium')),
+        ('BA', _(u'Bosnia and Herzegovina')),
+        ('BG', _(u'Bulgaria')),
+        ('HR', _(u'Croatia')),
+        ('CY', _(u'Cyprus')),
+        ('CZ', _(u'Czech Republic')),
+        ('DK', _(u'Denmark')),
+        ('EE', _(u'Estonia')),
+        ('FO', _(u'Faroe Islands')),
+        ('FI', _(u'Finland')),
+        ('FR', _(u'France')),
+        ('GE', _(u'Georgia')),
+        ('DE', _(u'Germany')),
+        ('GI', _(u'Gibraltar')),
+        ('GR', _(u'Greece')),
+        ('GL', _(u'Greenland')),
+        ('GG', _(u'Guernsey')),
+        ('HU', _(u'Hungary')),
+        ('IS', _(u'Iceland')),
+        ('IE', _(u'Ireland')),
+        ('IM', _(u'Isle of Man')),
+        ('IT', _(u'Italy')),
+        ('JE', _(u'Jersey')),
+        ('LV', _(u'Latvia')),
+        ('LI', _(u'Liechtenstein')),
+        ('LT', _(u'Lithuania')),
+        ('LU', _(u'Luxembourg')),
+        ('MK', _(u'Macedonia, The Former Yugoslav Republic of')),
+        ('MT', _(u'Malta')),
+        ('MD', _(u'Moldova')),
+        ('MC', _(u'Monaco')),
+        ('ME', _(u'Montenegro')),
+        ('NL', _(u'Netherlands')),
+        ('NO', _(u'Norway')),
+        ('PL', _(u'Poland')),
+        ('PT', _(u'Portugal')),
+        ('RO', _(u'Romania')),
+        ('SM', _(u'San Marino')),
+        ('RS', _(u'Serbia')),
+        ('SK', _(u'Slovakia')),
+        ('SI', _(u'Slovenia')),
+        ('ES', _(u'Spain')),
+        ('SJ', _(u'Svalbard and Jan Mayen')),
+        ('SE', _(u'Sweden')),
+        ('CH', _(u'Switzerland')),
+        ('UA', _(u'Ukraine')),
+        ('GB', _(u'United Kingdom')),
+        ('VA', _(u'Holy See (Vatican City State)')),
+        )),
+    (_(u'North America'),(
+        ('AS', _(u'American Samoa')),
+        ('AI', _(u'Anguilla')),
+        ('AG', _(u'Antigua and Barbuda')),
+        ('AW', _(u'Aruba')),
+        ('BS', _(u'Bahamas')),
+        ('BB', _(u'Barbados')),
+        ('BZ', _(u'Belize')),
+        ('BM', _(u'Bermuda')),
+        ('CA', _(u'Canada')),
+        ('KY', _(u'Cayman Islands')),
+        ('CR', _(u'Costa Rica')),
+        ('CU', _(u'Cuba')),
+        ('DM', _(u'Dominica')),
+        ('DO', _(u'Dominican Republic')),
+        ('SV', _(u'El Salvador')),
+        ('GD', _(u'Grenada')),
+        ('GP', _(u'Guadeloupe')),
+        ('GT', _(u'Guatemala')),
+        ('HT', _(u'Haiti')),
+        ('HN', _(u'Honduras')),
+        ('JM', _(u'Jamaica')),
+        ('MX', _(u'Mexico')),
+        ('MS', _(u'Montserrat')),
+        ('AN', _(u'Netherlands Antilles')),
+        ('NI', _(u'Nicaragua')),
+        ('PA', _(u'Panama')),
+        ('PR', _(u'Puerto Rico')),
+        ('BL', _(u'Saint Barthelemy')),
+        ('KN', _(u'Saint Kitts and Nevis')),
+        ('LC', _(u'Saint Lucia')),
+        ('MF', _(u'Saint Martin')),
+        ('PM', _(u'Saint Pierre and Miquelon')),
+        ('VC', _(u'Saint Vincent and the Grenadines')),
+        ('TT', _(u'Trinidad and Tobago')),
+        ('TC', _(u'Turks and Caicos Islands')),
+        ('US', _(u'United States')),
+        ('UM', _(u'United States Minor Outlying Islands')),
+        ('VG', _(u'Virgin Islands, British')),
+        ('VI', _(u'Virgin Islands, U.S.')),
+        )),
+    (_(u'Oceania'),(
+        ('AU', _(u'Australia')),
+        ('CX', _(u'Christmas Island')),
+        ('CC', _(u'Cocos (Keeling) Islands')),
+        ('CK', _(u'Cook Islands')),
+        ('FJ', _(u'Fiji')),
+        ('PF', _(u'French Polynesia')),
+        ('GU', _(u'Guam')),
+        ('KI', _(u'Kiribati')),
+        ('MH', _(u'Marshall Islands')),
+        ('FM', _(u'Micronesia, Federated States of')),
+        ('NR', _(u'Nauru')),
+        ('NC', _(u'New Caledonia')),
+        ('NZ', _(u'New Zealand')),
+        ('NU', _(u'Niue')),
+        ('NF', _(u'Norfolk Island')),
+        ('MP', _(u'Northern Mariana Islands')),
+        ('PW', _(u'Palau')),
+        ('PG', _(u'Papua New Guinea')),
+        ('PN', _(u'Pitcairn')),
+        ('WS', _(u'Samoa')),
+        ('SB', _(u'Solomon Islands')),
+        ('TK', _(u'Tokelau')),
+        ('TO', _(u'Tonga')),
+        ('TV', _(u'Tuvalu')),
+        ('VU', _(u'Vanuatu')),
+        ('WF', _(u'Wallis and Futuna')),
+        )),
+    (_(u'South America'),(
+        ('AR', _(u'Argentina')),
+        ('BO', _(u'Bolivia')),
+        ('BR', _(u'Brazil')),
+        ('CL', _(u'Chile')),
+        ('CO', _(u'Colombia')),
+        ('EC', _(u'Ecuador')),
+        ('FK', _(u'Falkland Islands (Malvinas)')),
+        ('GF', _(u'French Guiana')),
+        ('GY', _(u'Guyana')),
+        ('MQ', _(u'Martinique')),
+        ('PY', _(u'Paraguay')),
+        ('PE', _(u'Peru')),
+        ('GS', _(u'South Georgia and the South Sandwich Islands')),
+        ('SR', _(u'Suriname')),
+        ('UY', _(u'Uruguay')),
+        ('VE', _(u'Venezuela')),
+        )
+    ),
+)
+
+
 class CountryField(models.CharField):
     """
     Is a CharField with the complete list of countries as choices.
@@ -581,9 +588,11 @@ class ContinentCountryField(models.CharField):
     """
     Is a CharField with the complete list of countries as choices.
     """
+    
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('max_length', 2)
         kwargs.setdefault('choices', CONTINENT_COUNTRIES)
+        
         super(ContinentCountryField, self).__init__(*args, **kwargs)
 
     def get_internal_type(self):
